export interface GoogleAnalyticsEvent {
    name: string;
    params: Parameters<typeof JSON.stringify>[0];
}
export interface GoogleAnalyticsOptions {
    /**
     * The cookies associated with the request.
     */
    cookies: Partial<{
        [key: string]: string;
    }>;
    apiSecret?: string;
    measurementId?: string;
    /**
     * If enabled, will set `debug_mode: true`. See **Admin > DebugView**.
     *
     * @see https://support.google.com/analytics/answer/7201382#zippy=%2Cgoogle-tag-websites
     *
     */
    debug?: boolean;
}
/**
 * Send the given event items to the Google Analytics 4 data stream associated
 * with the given `GA_MEASUREMENT_ID`.
 *
 * @see https://developers.google.com/analytics/devguides/collection/protocol/ga4/sending-events
 *
 * @returns The status code of the request.
 */
export declare const googleAnalytics: ({ cookies, debug, apiSecret: api_secret, measurementId: measurement_id, }: GoogleAnalyticsOptions, ...events: GoogleAnalyticsEvent[]) => Promise<number | undefined>;
